Learn R Programming

NostalgiR (version 1.0.2)

nos.ecdf: nos.ecdf text-based plot of an empirical CDF.

Description

Plots a text-based empirical cumulative distribution function.

Usage

nos.ecdf(data, xlab = NULL, ratio = 0.25, width = round(options()$width * 0.8), height = round(ratio * width), pch = "o")

Arguments

data
A numeric vector containing the values to be plotted. NA and NaN are allowed, but are removed for the plot. Infinities will cause an error.
xlab
Label of the x-axis of the plot.
ratio
Coefficient that controls the aspect ratio of the plot.
width
Width of the plot in points.
height
Height of the plot in points.
pch
A single-character plot symbol.

See Also

ecdf, plot and txtplot.

Examples

Run this code
## Plot the empirical CDF of 10 random standard normal points with 'o' shaped points.
data <- rnorm(10)
nos.ecdf(data)

## Plot the empirical CDF of 100 random stanard normal points with '*' shaped points
data <- rnorm(100)
nos.ecdf(data,pch='*')

Run the code above in your browser using DataLab