Learn R Programming

NostalgiR (version 1.0.2)

nos.qqnorm: nos.qqnorm text-based normal quantile-quantile plots

Description

Produces a text-based normal quantile-quantile plot where the theoretical quantiles are plotted along the x-axis and the sample quantiles are plotted along the y-axis.

Usage

nos.qqnorm(data, line = T, ratio = 0.25, width = round(options()$width * 0.8), height = round(ratio * width), pch = c("o", "~"))

Arguments

data
A numeric vector containing the values to be plotted. NA and NaN are allowed, but are removed for the plot. Infinities will cause an error.
line
If TRUE, the line of theoretical quantile equality is plotted. If FALSE, then the line of theoretical quantile equality is not plotted.
ratio
Coefficient that controls the aspect ratio of the plot.
width
Width of the plot in points.
height
Height of the plot in points.
pch
A two dimensional vector of single-character symbols. The first symbol is for data point, and the second symbol is for the line of theoretical quantile equality.

See Also

qqnorm, qqline and txtplot.

Examples

Run this code
## Produce a normal quantile-quantile plot of 10 random standard normal points,
## without the line of theoretical quantile equality.
data <- rnorm(10)
nos.qqnorm(data,line=FALSE)

## Produce a normal quantile-quantile plot of 100 random chi-squared(3) points,
## with the line of theoretical quantile equality.
data <- rchisq(100,3)
nos.qqnorm(data)

Run the code above in your browser using DataLab